Crate apiw_sys

Crate apiw_sys 

Application Programming Interface for Windows (APIW) is a functional specification of the Microsoft Windows application programming interface, published as ECMA-234 in 1995.

This crate tries its best to faithfully provided the original interface defined within the specification, the implementation is based on the awesome windows-sys crate provided by Microsoft for the Rust community. It is well known that some of the functions has been deleted after the specification is published over the years, sometimes replaced by something else (usually with similiar namings!), so we also included those functions within this crate too.

Also, for the completeness of the EMF representable graphics subsystem operations, we expanded the API surface of graphics_subsystem feature to also include those operations added since then. EMF stands for Enhanced Metafile Format, an EMF metafile is a sequence of variable-length records that contain drawing commands, object definitions, and graphics properties to render a graphical image on any output device. Thus those drawing commands are provided as the major part of the graphics_subsystem. See the [MS-EMF] document supplied as part of the Microsoft Open Specifications collection for more details about it.

Modules

windows_subsystem
Section 2 - Windows Subsystem (6-167)
graphics_subsystem
Section 3 - Graphics Subsystem (168-304)
system_services
Section 4 - System Services (305-402)
application_support_functions
Section 5 - Application Support Functions (403-444)
extensions
Annex B - Unsupported Windows Functions (provided here as extensions)
all_data_structures
Annex C - Data Structures
all_messages
Annex D - Window Messages
all_control_notifications
Annex E - Control Notifications
all_window_styles
Annex F - Window Styles
all_macros
Annex G - Macros (experimental)
all_binary_raster_ops
Annex H - Binary Raster Operations

Macros

DECLARE_HANDLE
G.1 DECLARE_HANDLE
FIELDOFFSET
G.3 FIELDOFFSET
GetBValue
G.4 GetBValue
GetGValue
G.5 GetGValue
GetRValue
G.6 GetRValue
HIBYTE
G.7 HIBYTE
HIWORD
G.8 HIWORD
LOBYTE
G.9 LOBYTE
LOWORD
G.11 LOWORD
MAKEINTATOM
G.12 MAKEINTATOM
MAKEINTRESOURCE
G.13 MAKEINTRESOURCE
MAKELONG
G.14 MAKELONG
MAKELPARAM
G.16 MAKELPARAM
MAKELRESULT
G.17 MAKELRESULT
PALETTEINDEX
G.22 PALETTEINDEX
PALETTERGB
G.23 PALETTERGB
RGB
G.24 RGB