Annex H - Binary Raster Operations
Constants
- R2_
BLACK - Sets the pixel value in the destination bitmap to black
- R2_
WHITE - Sets the pixel value in the destination bitmap to white
- R2_
COPYPEN - Replaces the pixel value in the destination with the pixel value of the pen
- R2_
MASKNOTPEN - Replaces the pixel value of the destination with the result of the destination AND’ed with the INVERSE pixel value of the pen
- R2_
MASKPEN - Replaces the pixel value of the destination with the result of the destination bitmap AND’ed with the pixel value of the pen
- R2_
MASKPENNOT - Replaces the pixel value of the destination with the INVERSE of the destination bitmap pixel value AND’ed with the pixel value of the pen
- R2_
MERGENOTPEN - Replaces the pixel value of the destination with the result of the destination bitmap OR’ed with the INVERSE pixel value of the pen
- R2_
MERGEPEN - Replaces the pixel value of the destination with the result of the destination OR’ed with the pixel value of the pen
- R2_
MERGEPENNOT - Replaces the pixel value of the destination with the INVERSE of the destination bitmap pixel value OR’ed with the pixel value of the pen
- R2_NOP
- The destination bitmap is not altered
- R2_NOT
- INVERTs the value of the destination bitmap pixel value
- R2_
NOTCOPYPEN - Replaces the pixel value in the destination bitmap with the INVERSE of the pixel value of the pen
- R2_
NOTMASKPEN - Replaces the pixel value in the destination bitmap with the INVERSE result of the destination bitmap AND’ed with the pixel value of the pen
- R2_
NOTMERGEPEN - Replaces the pixel value of the destination bitmap with the INVERSE result of the destination bitmap OR’ed with the pixel value of the pen
- R2_
NOTXORPEN - Replaces the pixel value of the destination bitmap with the INVERSE result of the destination bitmap XOR’ed with the pixel value of the pen
- R2_
XORPEN - Replaces the pixel value of the destination bitmap with the result of the destination bitmap XOR’ed with the pixel value of the pen