CHOOSEFONT

Struct CHOOSEFONT 

#[repr(C)]
pub struct CHOOSEFONT {
Show 16 fields pub lStructSize: u32, pub hwndOwner: *mut c_void, pub hDC: *mut c_void, pub lpLogFont: *mut LOGFONTW, pub iPointSize: i32, pub Flags: u32, pub rgbColors: u32, pub lCustData: isize, pub lpfnHook: Option<unsafe extern "system" fn(*mut c_void, u32, usize, isize) -> usize>, pub lpTemplateName: *const u16, pub hInstance: *mut c_void, pub lpszStyle: *mut u16, pub nFontType: u16, pub ___MISSING_ALIGNMENT__: u16, pub nSizeMin: i32, pub nSizeMax: i32,
}
C.7 CHOOSEFONT

contains information that is used by the system to initialize the Font common dialog box and to return the user’s Font common dialog box selections

Fields

lStructSize: u32hwndOwner: *mut c_voidhDC: *mut c_voidlpLogFont: *mut LOGFONTWiPointSize: i32Flags: u32rgbColors: u32lCustData: isizelpfnHook: Option<unsafe extern "system" fn(*mut c_void, u32, usize, isize) -> usize>lpTemplateName: *const u16hInstance: *mut c_voidlpszStyle: *mut u16nFontType: u16___MISSING_ALIGNMENT__: u16nSizeMin: i32nSizeMax: i32