#[repr(C)]pub struct FINDREPLACE {
pub lStructSize: u32,
pub hwndOwner: *mut c_void,
pub hInstance: *mut c_void,
pub Flags: u32,
pub lpstrFindWhat: *mut u16,
pub lpstrReplaceWith: *mut u16,
pub wFindWhatLen: u16,
pub wReplaceWithLen: u16,
pub lCustData: isize,
pub lpfnHook: Option<unsafe extern "system" fn(*mut c_void, u32, usize, isize) -> usize>,
pub lpTemplateName: *const u16,
}Expand description
C.14 FINDREPLACE
contains information that is used by the system to initialize the Find and Replace common dialog boxes and to return the user’s dialog box selections
Fields
lStructSize: u32hwndOwner: *mut c_voidhInstance: *mut c_voidFlags: u32lpstrFindWhat: *mut u16lpstrReplaceWith: *mut u16wFindWhatLen: u16wReplaceWithLen: u16lCustData: isizelpfnHook: Option<unsafe extern "system" fn(*mut c_void, u32, usize, isize) -> usize>lpTemplateName: *const u16Trait Implementations
Sourceimpl Clone for FINDREPLACEW
impl Clone for FINDREPLACEW
Sourcefn clone(&self) -> FINDREPLACEW
fn clone(&self) -> FINDREPLACEW
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for FINDREPLACEW
Available on AArch64 or target_arch=arm64ec or x86-64 only.
impl Default for FINDREPLACEW
Available on AArch64 or
target_arch=arm64ec or x86-64 only.Sourcefn default() -> FINDREPLACEW
fn default() -> FINDREPLACEW
Returns the “default value” for a type. Read more
impl Copy for FINDREPLACEW