OPENFILENAME

Struct OPENFILENAME 

#[repr(C)]
pub struct OPENFILENAME {
Show 23 fields pub lStructSize: u32, pub hwndOwner: *mut c_void, pub hInstance: *mut c_void, pub lpstrFilter: *const u16, pub lpstrCustomFilter: *mut u16, pub nMaxCustFilter: u32, pub nFilterIndex: u32, pub lpstrFile: *mut u16, pub nMaxFile: u32, pub lpstrFileTitle: *mut u16, pub nMaxFileTitle: u32, pub lpstrInitialDir: *const u16, pub lpstrTitle: *const u16, pub Flags: u32, pub nFileOffset: u16, pub nFileExtension: u16, pub lpstrDefExt: *const u16, pub lCustData: isize, pub lpfnHook: Option<unsafe extern "system" fn(*mut c_void, u32, usize, isize) -> usize>, pub lpTemplateName: *const u16, pub pvReserved: *mut c_void, pub dwReserved: u32, pub FlagsEx: u32,
}
C.28 OPENFILENAME

contains information that is used by the system to initialize the Open and Save common dialog boxes and to return the user’s dialog box selections

Fields

lStructSize: u32hwndOwner: *mut c_voidhInstance: *mut c_voidlpstrFilter: *const u16lpstrCustomFilter: *mut u16nMaxCustFilter: u32nFilterIndex: u32lpstrFile: *mut u16nMaxFile: u32lpstrFileTitle: *mut u16nMaxFileTitle: u32lpstrInitialDir: *const u16lpstrTitle: *const u16Flags: u32nFileOffset: u16nFileExtension: u16lpstrDefExt: *const u16lCustData: isizelpfnHook: Option<unsafe extern "system" fn(*mut c_void, u32, usize, isize) -> usize>lpTemplateName: *const u16pvReserved: *mut c_voiddwReserved: u32FlagsEx: u32