#[repr(C)]pub struct PRINTDLG {Show 19 fields
pub lStructSize: u32,
pub hwndOwner: *mut c_void,
pub hDevMode: *mut c_void,
pub hDevNames: *mut c_void,
pub hDC: *mut c_void,
pub Flags: u32,
pub nFromPage: u16,
pub nToPage: u16,
pub nMinPage: u16,
pub nMaxPage: u16,
pub nCopies: u16,
pub hInstance: *mut c_void,
pub lCustData: isize,
pub lpfnPrintHook: Option<unsafe extern "system" fn(*mut c_void, u32, usize, isize) -> usize>,
pub lpfnSetupHook: Option<unsafe extern "system" fn(*mut c_void, u32, usize, isize) -> usize>,
pub lpPrintTemplateName: *const u16,
pub lpSetupTemplateName: *const u16,
pub hPrintTemplate: *mut c_void,
pub hSetupTemplate: *mut c_void,
}Expand description
C.32 PRINTDLG
contains information that is used by the system to initialize the Print common dialog box and to return the user’s dialog box selections
Fields
lStructSize: u32hwndOwner: *mut c_voidhDevMode: *mut c_voidhDevNames: *mut c_voidhDC: *mut c_voidFlags: u32nFromPage: u16nToPage: u16nMinPage: u16nMaxPage: u16nCopies: u16hInstance: *mut c_voidlCustData: isizelpfnPrintHook: Option<unsafe extern "system" fn(*mut c_void, u32, usize, isize) -> usize>lpfnSetupHook: Option<unsafe extern "system" fn(*mut c_void, u32, usize, isize) -> usize>lpPrintTemplateName: *const u16lpSetupTemplateName: *const u16hPrintTemplate: *mut c_voidhSetupTemplate: *mut c_voidTrait Implementations
Sourceimpl Default for PRINTDLGW
Available on (AArch64 or target_arch=arm64ec or x86-64) and crate feature Win32_Graphics_Gdi only.
impl Default for PRINTDLGW
Available on (AArch64 or
target_arch=arm64ec or x86-64) and crate feature Win32_Graphics_Gdi only.impl Copy for PRINTDLGW