Module all_window_styles

Module all_window_styles 

Annex F - Window Styles

Constants

MDIS_ALLCHILDSTYLES
Window is a multiple document interface (MDI) client window that can have any combination of window styles
WS_BORDER
Window has a border
WS_CAPTION
Window has a title bar and uses the WS_BORDER style
WS_CHILD
Window is a child window
WS_CHILDWINDOW
Same as the WS_CHILD style
WS_CLIPCHILDREN
When drawing within the parent window, the area occupied by child windows is excluded
WS_CLIPSIBLINGS
When a child window receives a paint message and needs to be updated, this style clips all other overlapped child windows out of the child window’s update region
WS_DISABLED
Window is initially disabled
WS_DLGFRAME
Window has a double border but no title
WS_GROUP
The style designates a control (a window) as being the first control in a group of controls
WS_MAXIMIZE
This style creates a window that has a maximum size
WS_MAXIMIZEBOX
This style creates a window that has a Maximize box
WS_MINIMIZE
This style creates a window that has a minimum size
WS_MINIMIZEBOX
This style creates a window that has a Minimize box
WS_OVERLAPPED
This style creates an overlapped window
WS_OVERLAPPEDWINDOW
This style creates an overlapped window that has the WS_OVERLAPPED, WS_CAPTION, WS_SYSMENU, WS_THICKFRAME, WS_MINIMIZEBOX, and WS_MAXIMIZEBOX styles
WS_POPUP
This style creates a pop-up window
WS_POPUPWINDOW
This style creates a pop-up window that has the WS_POPUP, WS_BORDER, and WS_SYSMENU styles
WS_SYSMENU
This style creates a window that has a System-menu box in its title bar
BS_3STATE
Creates a check box button that can be either checked, unchecked or grayed
BS_AUTO3STATE
Same as BS_3STATE, except each time the user clicks on it the state changes to the next state in the cycle: checked, grayed, or unchecked
BS_AUTOCHECKBOX
This check box alternates between being checked and unchecked each time the user clicks it
BS_AUTORADIOBUTTON
This button highlights itself when a user clicks it and causes any other button in the same group to become unhighlighted
BS_CHECKBOX
Creates a small square that can have an “X” within it, indicating that it is selected
BS_DEFPUSHBUTTON
Causes the button to have a heavy border and is automatically pushed if the user presses the ENTER key
BS_GROUPBOX
Creates a rectangle to group other buttons
BS_LEFTTEXT
Causes text to be placed on the left side of a radio button or check box
BS_OWNERDRAW
Creates an owner-drawn button
BS_PUSHBUTTON
Creates a rounded rectangle push button
BS_RADIOBUTTON
Creates a radio button that is a small circle with text displayed to the right or left of the circle
CBS_AUTOHSCROLL
If the combo box’s edit control is completely filled with text and the user enters more text at the end of the edit control line, the existing text is automatically scrolled
CBS_DISABLENOSCROLL
A scroll bar is always shown in the combo box’s list box
CBS_DROPDOWN
Similar to the CBS_SIMPLE style, the CBS_DROPDOWN style causes the combo box’s list box to be hidden until the user presses the Arrow button located next to the combo box’s edit control
CBS_DROPDOWNLIST
Similar to the CBS_DROPDOWN style, the CBS_DROPDOWNLIST style causes the combo box’s edit control to be set to read-only
CBS_HASSTRINGS
Declares that the entries in an owner-drawn combo box are strings
CBS_NOINTEGRALHEIGHT
If this style is not used, the system automatically resizes the height of the combo box so that none of its items are partially displayed
CBS_OEMCONVERT
When this style is used, text that is entered into the combo box’s edit control is automatically converted from the system’s character set to the OEM character set and then back again to the system’s character set
CBS_OWNERDRAWFIXED
When this style is used, the system makes the owner of the combo box responsible for drawing its contents and the height of all of the list box’s items is the same
CBS_OWNERDRAWVARIABLE
When this style is used, the system makes the owner of the combo box responsible for drawing its contents and the height of each of the list box’s items is not the same
CBS_SIMPLE
When this style is used, the combo box’s list box is always displayed
CBS_SORT
The combo box’s list box entries are automatically sorted
ES_AUTOHSCROLL
Creates an edit control that automatically scrolls horizontally as text is entered
ES_AUTOVSCROLL
Creates an edit control that automatically scrolls vertically when there is more text than can be displayed within the control
ES_CENTER
Specifies that multiline edit controls center justify text
ES_LEFT
Specifies that the edit control left justify its text
ES_LOWERCASE
All uppercase characters entered into the edit control is displayed as lowercase
ES_MULTILINE
Causes the edit control to be a multiline control
ES_NOHIDESEL
Negates the default behavior for an edit control, which is to hide the selection when the control loses the input focus and invert the selection when the control receives the input focus
ES_OEMCONVERT
Converts text entered in the edit control from the default character set to the OEM character set and then back to the default character set
ES_PASSWORD
Hides all characters and displays them as an asterisk as they are typed into the edit control
ES_READONLY
Prevents the user from typing or editing text in the edit control
ES_RIGHT
Right aligns text in a multiline edit control
ES_UPPERCASE
Converts all characters to uppercase as they are typed into the edit control
ES_WANTRETURN
Specifies that a carriage return be inserted when the user presses the ENTER key while entering text into a multiline edit control
LBS_DISABLENOSCROLL
Shows a disabled vertical scroll bar for the list box when the box does not contain enough items to scroll
LBS_EXTENDEDSEL
Allows multiple items to be selected by using the SHIFT key and the mouse, or special key combinations
LBS_HASSTRINGS
Specifies that a list box contains items consisting of strings
LBS_MULTICOLUMN
Specifies a multicolumn list box that is scrolled horizontally
LBS_MULTIPLESEL
This list box style allows for the selection of any number of strings
LBS_NOINTEGRALHEIGHT
This list box style prevents the height of a list box from being adjusted so that partial items are not displayed
LBS_NOREDRAW
This list box style suppresses screen updates when changes are made
LBS_NOTIFY
This list box style enables the notification of the parent window when a string in the list box is clicked or double-clicked
LBS_OWNERDRAWFIXED
This list box style specifies that the application is responsible for drawing the list box and that all the items have the same height
LBS_OWNERDRAWVARIABLE
This list box style specifies that the application is responsible for drawing the list box and that the items in the list box vary in height
LBS_SORT
This list box style causes the list box strings to be sorted alphabetically
LBS_STANDARD
This list box style combines the LBS_NOTIFY and LBS_SORT list box styles with the windows styles WS_BORDER and WS_VSCROLL
LBS_USETABSTOPS
This list box style expands tab characters within its content strings
LBS_WANTKEYBOARDINPUT
This list box style indicates that the owner receives WM_VKEYTOITEM or WM_CHARTOITEM messages when the list box has input focus and the user presses a key
SBS_BOTTOMALIGN
The bottom edge of the scroll bar is aligned with the bottom edge of the rectangle given by the CreateWindow() function’s parameters
SBS_HORZ
Has a horizontal scroll bar
SBS_LEFTALIGN
The left edge of the scroll bar is aligned with the left edge of the rectangle given by the CreateWindow() function’s parameters
SBS_RIGHTALIGN
The right edge of the scroll bar is aligned with the right edge of the rectangle given by the CreateWindow() function’s parameters
SBS_SIZEBOX
Has a size box
SBS_SIZEBOXBOTTOMRIGHTALIGN
The lower-right corner of the size box is aligned with the lower-right corner of the rectangle given by the CreateWindow() function’s parameters
SBS_SIZEBOXTOPLEFTALIGN
The upper-left corner of the size box is aligned with the upper-left corner of the rectangle given by the CreateWindow() function’s parameters
SBS_TOPALIGN
The top edge of the scroll bar is aligned with the top edge of the rectangle given by the CreateWindow() parameters
SBS_VERT
Has a vertical scroll bar
SS_BLACKFRAME
Specifies a box with a frame drawn with the same color as window frames
SS_BLACKRECT
Specifies a rectangle filled with the same color as window frames
SS_CENTER
Specifies a simple rectangle and aligns the displayed text in the center
SS_GRAYFRAME
Specifies a box with a frame drawn with the same color as the desktop
SS_GRAYRECT
Specifies a rectangle filled with the color used to fill the screen background
SS_ICON
Designates an icon displayed in the dialog box
SS_LEFT
Designates a simple rectangle and left-aligns the displayed text
SS_LEFTNOWORDWRAP
Designates a simple rectangle and left-aligns the displayed text in the rectangle
SS_NOPREFIX
Prevents interpretation of any ampersand (&) characters in the control’s text as accelerator prefix characters (which are displayed with the & character removed and the next character in the string underlined)
SS_RIGHT
Designates a simple rectangle and right-aligns the displayed text in the rectangle
SS_SIMPLE
Designates a simple rectangle and displays a single line of text left-aligned in the rectangle
SS_WHITEFRAME
Designates a frame drawn in the same color as the window background
SS_WHITERECT
Designates a rectangle filled with the window background color
DS_MODALFRAME
Creates a dialog box with a modal frame
DS_NOIDLEMSG
Tells the system not to send WM_ENTERIDLE messages to the owner of the dialog box while the dialog box is displayed
DS_SYSMODAL
Creates a system modal dialog box