ChooseFont

Function ChooseFont 

pub unsafe extern "system" fn ChooseFont(
    param0: *mut CHOOSEFONTW,
) -> i32
#438 ChooseFont

provides the user with a modal dialog box, under the control of the lpcf parameter, which allows for the interactive selection of a font