FindText

Function FindText 

pub unsafe extern "system" fn FindText(
    param0: *mut FINDREPLACEW,
) -> *mut c_void
#439 FindText

create modeless dialog boxes, under the control of the lpfr parameter, that make it possible for users to find text within a document