CHOOSECOLOR

Struct CHOOSECOLOR 

#[repr(C)]
pub struct CHOOSECOLOR { pub lStructSize: u32, pub hwndOwner: *mut c_void, pub hInstance: *mut c_void, pub rgbResult: u32, pub lpCustColors: *mut u32, pub Flags: u32, pub lCustData: isize, pub lpfnHook: Option<unsafe extern "system" fn(*mut c_void, u32, usize, isize) -> usize>, pub lpTemplateName: *const u16, }
C.6 CHOOSECOLOR

contains information that is used by the system to initialize the Color common dialog box and to return the user’s Color common dialog box selections

Fields

lStructSize: u32hwndOwner: *mut c_voidhInstance: *mut c_voidrgbResult: u32lpCustColors: *mut u32Flags: u32lCustData: isizelpfnHook: Option<unsafe extern "system" fn(*mut c_void, u32, usize, isize) -> usize>lpTemplateName: *const u16