#[repr(C)]pub struct CHOOSEFONT {Show 16 fields
pub lStructSize: u32,
pub hwndOwner: *mut c_void,
pub hDC: *mut c_void,
pub lpLogFont: *mut LOGFONTW,
pub iPointSize: i32,
pub Flags: u32,
pub rgbColors: u32,
pub lCustData: isize,
pub lpfnHook: Option<unsafe extern "system" fn(*mut c_void, u32, usize, isize) -> usize>,
pub lpTemplateName: *const u16,
pub hInstance: *mut c_void,
pub lpszStyle: *mut u16,
pub nFontType: u16,
pub ___MISSING_ALIGNMENT__: u16,
pub nSizeMin: i32,
pub nSizeMax: i32,
}Expand description
C.7 CHOOSEFONT
contains information that is used by the system to initialize the Font common dialog box and to return the user’s Font common dialog box selections
Fields
lStructSize: u32hwndOwner: *mut c_voidhDC: *mut c_voidlpLogFont: *mut LOGFONTWiPointSize: i32Flags: u32rgbColors: u32lCustData: isizelpfnHook: Option<unsafe extern "system" fn(*mut c_void, u32, usize, isize) -> usize>lpTemplateName: *const u16hInstance: *mut c_voidlpszStyle: *mut u16nFontType: u16___MISSING_ALIGNMENT__: u16nSizeMin: i32nSizeMax: i32Trait Implementations
Sourceimpl Clone for CHOOSEFONTW
impl Clone for CHOOSEFONTW
Sourcefn clone(&self) -> CHOOSEFONTW
fn clone(&self) -> CHOOSEFONTW
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CHOOSEFONTW
Available on (AArch64 or target_arch=arm64ec or x86-64) and crate feature Win32_Graphics_Gdi only.
impl Default for CHOOSEFONTW
Available on (AArch64 or
target_arch=arm64ec or x86-64) and crate feature Win32_Graphics_Gdi only.Sourcefn default() -> CHOOSEFONTW
fn default() -> CHOOSEFONTW
Returns the “default value” for a type. Read more
impl Copy for CHOOSEFONTW