CreateFontIndirect

Function CreateFontIndirect 

pub unsafe extern "system" fn CreateFontIndirect(
    lplf: *const LOGFONTW,
) -> *mut c_void
#272 CreateFontIndirect

creates the font, but uses a structure to encompass the parameters which are individually passed to CreateFont()