CreatePolygonRgn

Function CreatePolygonRgn 

pub unsafe extern "system" fn CreatePolygonRgn(
    pptl: *const POINT,
    cpoint: i32,
    imode: i32,
) -> *mut c_void
#225 CreatePolygonRgn

allocate storage for the region structure, initialize it to make a polygon region, and return a handle to the new region