DrawText

Function DrawText 

pub unsafe extern "system" fn DrawText(
    hdc: *mut c_void,
    lpchtext: *const u16,
    cchtext: i32,
    lprc: *mut RECT,
    format: u32,
) -> i32
#282 DrawText

draws Count bytes of String to the device-context specified in the hdc parameter using the device-context’s output position, selected font, background and text colors