GetBitmapDimensionEx

Function GetBitmapDimensionEx 

pub unsafe extern "system" fn GetBitmapDimensionEx(
    hbit: *mut c_void,
    lpsize: *mut SIZE,
) -> i32
#268 GetBitmapDimensionEx

returns the dimensions of the bitmap specified by hbmp and stores the dimension information in the POINT structure given in the lpSize parameter