GetNearestColor

Function GetNearestColor 

pub unsafe extern "system" fn GetNearestColor(
    hdc: *mut c_void,
    color: u32,
) -> u32
#190 GetNearestColor

finds a solid color that can be represented in the given device-context and that is closest to the specified color