GetViewportExtEx

Function GetViewportExtEx 

pub unsafe extern "system" fn GetViewportExtEx(
    hdc: *mut c_void,
    lpsize: *mut SIZE,
) -> i32
#206 GetViewportExtEx

using the handle of the device-context found in the hdc parameter, retrieves the vertical and horizontal dimensions, in device units, of the device-context’s viewport