GrayString

Function GrayString 

pub unsafe extern "system" fn GrayString(
    hdc: *mut c_void,
    hbrush: *mut c_void,
    lpoutputfunc: Option<unsafe extern "system" fn(*mut c_void, isize, i32) -> i32>,
    lpdata: isize,
    ncount: i32,
    x: i32,
    y: i32,
    nwidth: i32,
    nheight: i32,
) -> i32
#290 GrayString

draws gray text in a specified device-context, hdc, using the brush handle specified in the Brush parameter and the solid gray system color defined by the constant COLOR_GRAYTEXT