LineTo

Function LineTo 

pub unsafe extern "system" fn LineTo(
    hdc: *mut c_void,
    x: i32,
    y: i32,
) -> i32
#249 LineTo

draws a straight line from the current position to the point indicated by the X and Y parameters which becomes the new position

See also

  • MS-EMF:v14 2.3.5.13 EMR_LINETO Record