SelectClipPath

Function SelectClipPath 

pub unsafe extern "system" fn SelectClipPath(
    hdc: *mut c_void,
    mode: i32,
) -> i32
METAFILE#5 SelectClipPath

sets the current clipping region in the playback device context to the current clipping region combined with current path bracket

See also

  • MS-EMF:v14 2.3.2.5 EMR_SELECTCLIPPATH Record