SetBitmapDimensionEx

Function SetBitmapDimensionEx 

pub unsafe extern "system" fn SetBitmapDimensionEx(
    hbm: *mut c_void,
    w: i32,
    h: i32,
    lpsz: *mut SIZE,
) -> i32
#269 SetBitmapDimensionEx

set the dimensions of the bitmap specified by hbmp and stores the old dimensions in a given POINT structure