TextOut

Function TextOut 

pub unsafe extern "system" fn TextOut(
    hdc: *mut c_void,
    x: i32,
    y: i32,
    lpstring: *const u16,
    c: i32,
) -> i32
#283 TextOut

draws Count bytes of a text string pointed to by the String parameter in the specified device-context using the hdc’s selected font, background and text colors