macro_rules! DECLARE_HANDLE {
($v:vis $n:ident) => { ... };
}Expand description
G.1 DECLARE_HANDLE
define a data type that has the name specified in the parameter
macro_rules! DECLARE_HANDLE {
($v:vis $n:ident) => { ... };
}G.1 DECLARE_HANDLE
define a data type that has the name specified in the parameter