macro_rules! FIELDOFFSET {
($structure:ty, $element:ident $(,)?) => { ... };
}Expand description
G.3 FIELDOFFSET
retrieves the address offset of an element that is inside of a structure
macro_rules! FIELDOFFSET {
($structure:ty, $element:ident $(,)?) => { ... };
}G.3 FIELDOFFSET
retrieves the address offset of an element that is inside of a structure