macro_rules! MAKEINTRESOURCE {
($e:expr) => { ... };
}Expand description
G.13 MAKEINTRESOURCE
processed a resource’s identifier and returns it in a form that will be understood by the API’s resource-management functions
macro_rules! MAKEINTRESOURCE {
($e:expr) => { ... };
}G.13 MAKEINTRESOURCE
processed a resource’s identifier and returns it in a form that will be understood by the API’s resource-management functions