macro_rules! PALETTEINDEX {
($e:expr) => { ... };
}Expand description
G.22 PALETTEINDEX
creates a palette-relative RGB specifier from the specified index to a logical-color palette entry passed to the macro
macro_rules! PALETTEINDEX {
($e:expr) => { ... };
}G.22 PALETTEINDEX
creates a palette-relative RGB specifier from the specified index to a logical-color palette entry passed to the macro