pub unsafe extern "system" fn GetDoubleClickTime() -> u32
#311 GetDoubleClickTime
#311
returns the maximum number of milliseconds that can occur between the first and second mouse button clicks of a mouse button double-click