GetSystemMetrics

Function GetSystemMetrics 

pub unsafe extern "system" fn GetSystemMetrics(nindex: i32) -> i32
#308 GetSystemMetrics

retrieves information about the width and height, in pixels, of the various elements displayed by the system and also retrieves some other miscellaneous system information