LockResource

Function LockResource 

pub unsafe extern "system" fn LockResource(
    hresdata: *mut c_void,
) -> *mut c_void
#358 LockResource

locks a resource that has been loaded into global memory and returns a pointer to the resource’s data