RegEnumKey

Function RegEnumKey 

pub unsafe extern "system" fn RegEnumKey(
    hkey: *mut c_void,
    dwindex: u32,
    lpname: *mut u16,
    cchname: u32,
) -> u32
#395 RegEnumKey

enumerates the subkeys of the Registration Database entry specified by the hkey parameter, an open handle (which can be HKEY_CLASSES_ROOT)