CheckRadioButton

Function CheckRadioButton 

pub unsafe extern "system" fn CheckRadioButton(
    hdlg: *mut c_void,
    nidfirstbutton: i32,
    nidlastbutton: i32,
    nidcheckbutton: i32,
) -> i32
#130 CheckRadioButton

checks one radio button from a group and removes check marks from any other radio buttons in the group