CreateDialogParam

Function CreateDialogParam 

pub unsafe extern "system" fn CreateDialogParam(
    hinstance: *mut c_void,
    lptemplatename: *const u16,
    hwndparent: *mut c_void,
    lpdialogfunc: Option<unsafe extern "system" fn(*mut c_void, u32, usize, isize) -> isize>,
    dwinitparam: isize,
) -> *mut c_void
#132 CreateDialogParam

create a modeless dialog, allowing a value to be passed to the dialog procedure in the WM_INITDIALOG message