GetClassLong

Function GetClassLong 

pub unsafe extern "system" fn GetClassLong(
    hwnd: *mut c_void,
    nindex: i32,
) -> u32
#25 GetClassLong

retrieve a long value at the specified offset from extra memory associated with the class associated with the specified window