GetMessagePos

Function GetMessagePos 

pub unsafe extern "system" fn GetMessagePos() -> u32
#10 GetMessagePos

returns a long value representing a cursor position, in screen coordinates, when the last message retrieved by the GetMessage() function occurs