pub unsafe extern "system" fn GetPriorityClipboardFormat(
paformatprioritylist: *const u32,
cformats: i32,
) -> i32Expand description
#116 GetPriorityClipboardFormat
accepts a list of clipboard format identifiers and returns the identifier of the first clipboard format for which data exists in the clipboard