GetQueueStatus

Function GetQueueStatus 

pub unsafe extern "system" fn GetQueueStatus(flags: u32) -> u32
#20 GetQueueStatus

determines whether any new messages were put in the message queue since the last time the GetQueueStatus(), GetMessage(), or PeekMessage() functions were called