GetUpdateRect

Function GetUpdateRect 

pub unsafe extern "system" fn GetUpdateRect(
    hwnd: *mut c_void,
    lprect: *mut RECT,
    berase: i32,
) -> i32
#153 GetUpdateRect

gets the coordinates of the smallest rectangle that completely encloses a region of the hwnd window that is updated