InSendMessage

Function InSendMessage 

pub unsafe extern "system" fn InSendMessage() -> i32
#11 InSendMessage

determines whether the current window procedure is processing a message sent from another task by a call to the SendMessage() function