SetMenuItemBitmaps

Function SetMenuItemBitmaps 

pub unsafe extern "system" fn SetMenuItemBitmaps(
    hmenu: *mut c_void,
    uposition: u32,
    uflags: u32,
    hbitmapunchecked: *mut c_void,
    hbitmapchecked: *mut c_void,
) -> i32
#79 SetMenuItemBitmaps

sets the custom check mark bitmaps for a menu item from the menu specified in the hMenu parameter