TrackPopupMenu

Function TrackPopupMenu 

pub unsafe extern "system" fn TrackPopupMenu(
    hmenu: *mut c_void,
    uflags: u32,
    x: i32,
    y: i32,
    nreserved: i32,
    hwnd: *mut c_void,
    prcrect: *const RECT,
) -> i32
#80 TrackPopupMenu

displays the pop-up menu handle of the menu specified in the hMenu parameter and tracks the selection events resulting from mouse or keyboard input to the specified menu and its sub-menus