ValidateRect

Function ValidateRect 

pub unsafe extern "system" fn ValidateRect(
    hwnd: *mut c_void,
    lprect: *const RECT,
) -> i32
#167 ValidateRect

validates the rectangular part of the client area, specified by lprc parameter by removing that rectangle from the window’s update region