pub type GetMsgProc = <HOOKPROC as OptInner>::Inner;Expand description
#121 GetMsgProc
called by the system when a GetMessage() function has fetched a message from the application queue
pub type GetMsgProc = <HOOKPROC as OptInner>::Inner;#121 GetMsgProc
called by the system when a GetMessage() function has fetched a message from the application queue