MessageProc

Type Alias MessageProc 

pub type MessageProc = <HOOKPROC as OptInner>::Inner;
#122 MessageProc

called by the system after a dialog box, message box, or menu has fetched a message that has not been processed