pub type SysMsgProc = <HOOKPROC as OptInner>::Inner;Expand description
#123 SysMsgProc
called by the system after a dialog box, message box, or menu has fetched a message but before the message has been processed
pub type SysMsgProc = <HOOKPROC as OptInner>::Inner;#123 SysMsgProc
called by the system after a dialog box, message box, or menu has fetched a message but before the message has been processed