pub type WindowProc = <WNDPROC as OptInner>::Inner;Expand description
#29 WindowProc
an application-defined callback procedure that processes messages sent to the window
pub type WindowProc = <WNDPROC as OptInner>::Inner;#29 WindowProc
an application-defined callback procedure that processes messages sent to the window