Module all_binary_raster_ops

Module all_binary_raster_ops 

Annex H - Binary Raster Operations

Constants

R2_BLACK
Sets the pixel value in the destination bitmap to black
R2_WHITE
Sets the pixel value in the destination bitmap to white
R2_COPYPEN
Replaces the pixel value in the destination with the pixel value of the pen
R2_MASKNOTPEN
Replaces the pixel value of the destination with the result of the destination AND’ed with the INVERSE pixel value of the pen
R2_MASKPEN
Replaces the pixel value of the destination with the result of the destination bitmap AND’ed with the pixel value of the pen
R2_MASKPENNOT
Replaces the pixel value of the destination with the INVERSE of the destination bitmap pixel value AND’ed with the pixel value of the pen
R2_MERGENOTPEN
Replaces the pixel value of the destination with the result of the destination bitmap OR’ed with the INVERSE pixel value of the pen
R2_MERGEPEN
Replaces the pixel value of the destination with the result of the destination OR’ed with the pixel value of the pen
R2_MERGEPENNOT
Replaces the pixel value of the destination with the INVERSE of the destination bitmap pixel value OR’ed with the pixel value of the pen
R2_NOP
The destination bitmap is not altered
R2_NOT
INVERTs the value of the destination bitmap pixel value
R2_NOTCOPYPEN
Replaces the pixel value in the destination bitmap with the INVERSE of the pixel value of the pen
R2_NOTMASKPEN
Replaces the pixel value in the destination bitmap with the INVERSE result of the destination bitmap AND’ed with the pixel value of the pen
R2_NOTMERGEPEN
Replaces the pixel value of the destination bitmap with the INVERSE result of the destination bitmap OR’ed with the pixel value of the pen
R2_NOTXORPEN
Replaces the pixel value of the destination bitmap with the INVERSE result of the destination bitmap XOR’ed with the pixel value of the pen
R2_XORPEN
Replaces the pixel value of the destination bitmap with the result of the destination bitmap XOR’ed with the pixel value of the pen