Annex F - Window Styles
Constants
- MDIS_
ALLCHILDSTYLES - Window is a multiple document interface (MDI) client window that can have any combination of window styles
- WS_
BORDER - Window has a border
- WS_
CAPTION - Window has a title bar and uses the
WS_BORDERstyle - WS_
CHILD - Window is a child window
- WS_
CHILDWINDOW - Same as the
WS_CHILDstyle - WS_
CLIPCHILDREN - When drawing within the parent window, the area occupied by child windows is excluded
- WS_
CLIPSIBLINGS - When a child window receives a paint message and needs to be updated, this style clips all other overlapped child windows out of the child window’s update region
- WS_
DISABLED - Window is initially disabled
- WS_
DLGFRAME - Window has a double border but no title
- WS_
GROUP - The style designates a control (a window) as being the first control in a group of controls
- WS_
MAXIMIZE - This style creates a window that has a maximum size
- WS_
MAXIMIZEBOX - This style creates a window that has a Maximize box
- WS_
MINIMIZE - This style creates a window that has a minimum size
- WS_
MINIMIZEBOX - This style creates a window that has a Minimize box
- WS_
OVERLAPPED - This style creates an overlapped window
- WS_
OVERLAPPEDWINDOW - This style creates an overlapped window that has the
WS_OVERLAPPED,WS_CAPTION,WS_SYSMENU,WS_THICKFRAME,WS_MINIMIZEBOX, andWS_MAXIMIZEBOXstyles - WS_
POPUP - This style creates a pop-up window
- WS_
POPUPWINDOW - This style creates a pop-up window that has the
WS_POPUP,WS_BORDER, andWS_SYSMENUstyles - WS_
SYSMENU - This style creates a window that has a System-menu box in its title bar
- BS_
3STATE - Creates a check box button that can be either checked, unchecked or grayed
- BS_
AUTO3STATE - Same as
BS_3STATE, except each time the user clicks on it the state changes to the next state in the cycle: checked, grayed, or unchecked - BS_
AUTOCHECKBOX - This check box alternates between being checked and unchecked each time the user clicks it
- BS_
AUTORADIOBUTTON - This button highlights itself when a user clicks it and causes any other button in the same group to become unhighlighted
- BS_
CHECKBOX - Creates a small square that can have an “X” within it, indicating that it is selected
- BS_
DEFPUSHBUTTON - Causes the button to have a heavy border and is automatically pushed if the user presses the ENTER key
- BS_
GROUPBOX - Creates a rectangle to group other buttons
- BS_
LEFTTEXT - Causes text to be placed on the left side of a radio button or check box
- BS_
OWNERDRAW - Creates an owner-drawn button
- BS_
PUSHBUTTON - Creates a rounded rectangle push button
- BS_
RADIOBUTTON - Creates a radio button that is a small circle with text displayed to the right or left of the circle
- CBS_
AUTOHSCROLL - If the combo box’s edit control is completely filled with text and the user enters more text at the end of the edit control line, the existing text is automatically scrolled
- CBS_
DISABLENOSCROLL - A scroll bar is always shown in the combo box’s list box
- CBS_
DROPDOWN - Similar to the
CBS_SIMPLEstyle, theCBS_DROPDOWNstyle causes the combo box’s list box to be hidden until the user presses the Arrow button located next to the combo box’s edit control - CBS_
DROPDOWNLIST - Similar to the
CBS_DROPDOWNstyle, theCBS_DROPDOWNLISTstyle causes the combo box’s edit control to be set to read-only - CBS_
HASSTRINGS - Declares that the entries in an owner-drawn combo box are strings
- CBS_
NOINTEGRALHEIGHT - If this style is not used, the system automatically resizes the height of the combo box so that none of its items are partially displayed
- CBS_
OEMCONVERT - When this style is used, text that is entered into the combo box’s edit control is automatically converted from the system’s character set to the OEM character set and then back again to the system’s character set
- CBS_
OWNERDRAWFIXED - When this style is used, the system makes the owner of the combo box responsible for drawing its contents and the height of all of the list box’s items is the same
- CBS_
OWNERDRAWVARIABLE - When this style is used, the system makes the owner of the combo box responsible for drawing its contents and the height of each of the list box’s items is not the same
- CBS_
SIMPLE - When this style is used, the combo box’s list box is always displayed
- CBS_
SORT - The combo box’s list box entries are automatically sorted
- ES_
AUTOHSCROLL - Creates an edit control that automatically scrolls horizontally as text is entered
- ES_
AUTOVSCROLL - Creates an edit control that automatically scrolls vertically when there is more text than can be displayed within the control
- ES_
CENTER - Specifies that multiline edit controls center justify text
- ES_LEFT
- Specifies that the edit control left justify its text
- ES_
LOWERCASE - All uppercase characters entered into the edit control is displayed as lowercase
- ES_
MULTILINE - Causes the edit control to be a multiline control
- ES_
NOHIDESEL - Negates the default behavior for an edit control, which is to hide the selection when the control loses the input focus and invert the selection when the control receives the input focus
- ES_
OEMCONVERT - Converts text entered in the edit control from the default character set to the OEM character set and then back to the default character set
- ES_
PASSWORD - Hides all characters and displays them as an asterisk as they are typed into the edit control
- ES_
READONLY - Prevents the user from typing or editing text in the edit control
- ES_
RIGHT - Right aligns text in a multiline edit control
- ES_
UPPERCASE - Converts all characters to uppercase as they are typed into the edit control
- ES_
WANTRETURN - Specifies that a carriage return be inserted when the user presses the ENTER key while entering text into a multiline edit control
- LBS_
DISABLENOSCROLL - Shows a disabled vertical scroll bar for the list box when the box does not contain enough items to scroll
- LBS_
EXTENDEDSEL - Allows multiple items to be selected by using the SHIFT key and the mouse, or special key combinations
- LBS_
HASSTRINGS - Specifies that a list box contains items consisting of strings
- LBS_
MULTICOLUMN - Specifies a multicolumn list box that is scrolled horizontally
- LBS_
MULTIPLESEL - This list box style allows for the selection of any number of strings
- LBS_
NOINTEGRALHEIGHT - This list box style prevents the height of a list box from being adjusted so that partial items are not displayed
- LBS_
NOREDRAW - This list box style suppresses screen updates when changes are made
- LBS_
NOTIFY - This list box style enables the notification of the parent window when a string in the list box is clicked or double-clicked
- LBS_
OWNERDRAWFIXED - This list box style specifies that the application is responsible for drawing the list box and that all the items have the same height
- LBS_
OWNERDRAWVARIABLE - This list box style specifies that the application is responsible for drawing the list box and that the items in the list box vary in height
- LBS_
SORT - This list box style causes the list box strings to be sorted alphabetically
- LBS_
STANDARD - This list box style combines the
LBS_NOTIFYandLBS_SORTlist box styles with the windows stylesWS_BORDERandWS_VSCROLL - LBS_
USETABSTOPS - This list box style expands tab characters within its content strings
- LBS_
WANTKEYBOARDINPUT - This list box style indicates that the owner receives
WM_VKEYTOITEMorWM_CHARTOITEMmessages when the list box has input focus and the user presses a key - SBS_
BOTTOMALIGN - The bottom edge of the scroll bar is aligned with the bottom edge of the rectangle given by the CreateWindow() function’s parameters
- SBS_
HORZ - Has a horizontal scroll bar
- SBS_
LEFTALIGN - The left edge of the scroll bar is aligned with the left edge of the rectangle given by the CreateWindow() function’s parameters
- SBS_
RIGHTALIGN - The right edge of the scroll bar is aligned with the right edge of the rectangle given by the CreateWindow() function’s parameters
- SBS_
SIZEBOX - Has a size box
- SBS_
SIZEBOXBOTTOMRIGHTALIGN - The lower-right corner of the size box is aligned with the lower-right corner of the rectangle given by the CreateWindow() function’s parameters
- SBS_
SIZEBOXTOPLEFTALIGN - The upper-left corner of the size box is aligned with the upper-left corner of the rectangle given by the CreateWindow() function’s parameters
- SBS_
TOPALIGN - The top edge of the scroll bar is aligned with the top edge of the rectangle given by the CreateWindow() parameters
- SBS_
VERT - Has a vertical scroll bar
- SS_
BLACKFRAME - Specifies a box with a frame drawn with the same color as window frames
- SS_
BLACKRECT - Specifies a rectangle filled with the same color as window frames
- SS_
CENTER - Specifies a simple rectangle and aligns the displayed text in the center
- SS_
GRAYFRAME - Specifies a box with a frame drawn with the same color as the desktop
- SS_
GRAYRECT - Specifies a rectangle filled with the color used to fill the screen background
- SS_ICON
- Designates an icon displayed in the dialog box
- SS_LEFT
- Designates a simple rectangle and left-aligns the displayed text
- SS_
LEFTNOWORDWRAP - Designates a simple rectangle and left-aligns the displayed text in the rectangle
- SS_
NOPREFIX - Prevents interpretation of any ampersand (&) characters in the control’s text as accelerator prefix characters (which are displayed with the & character removed and the next character in the string underlined)
- SS_
RIGHT - Designates a simple rectangle and right-aligns the displayed text in the rectangle
- SS_
SIMPLE - Designates a simple rectangle and displays a single line of text left-aligned in the rectangle
- SS_
WHITEFRAME - Designates a frame drawn in the same color as the window background
- SS_
WHITERECT - Designates a rectangle filled with the window background color
- DS_
MODALFRAME - Creates a dialog box with a modal frame
- DS_
NOIDLEMSG - Tells the system not to send
WM_ENTERIDLEmessages to the owner of the dialog box while the dialog box is displayed - DS_
SYSMODAL - Creates a system modal dialog box