pub unsafe extern "system" fn ChooseColor(
param0: *mut CHOOSECOLORW,
) -> i32Expand description
#437 ChooseColor
provides the user with a modal dialog box, under the control of the lpcc
parameter, to allow for the interactive selection of a color or colors