pub unsafe extern "system" fn CommDlgExtendedError() -> u32
#443 CommDlgExtendedError
#443
The last error encountered during execution of one of the common dialog functions is saved and can be retrieved by this function