pub unsafe extern "system" fn GetOpenFileName(
param0: *mut OPENFILENAMEW,
) -> i32Expand description
#440 GetOpenFileName
provide the user with a modal dialog box, under the control of the lpof
parameter, which allows for the interactive selection of a file, with the
ability to open, create and verify the file