pub unsafe extern "system" fn InflateRect( lprc: *mut RECT, dx: i32, dy: i32, ) -> i32
#423 InflateRect
#423
adds x to the right and left elements, and y to the top and bottom elements of the specified triangle