pub unsafe extern "system" fn ReplaceText(
param0: *mut FINDREPLACEW,
) -> *mut c_voidExpand description
#439 ReplaceText
create modeless dialog boxes, under the control of the lpfr parameter,
that make it possible for users to find text within a document