WriteProfileString

Function WriteProfileString 

pub unsafe extern "system" fn WriteProfileString(
    lpappname: *const u16,
    lpkeyname: *const u16,
    lpstring: *const u16,
) -> i32
#406 WriteProfileString

write out a key string and its associated data to the requested section of the default win.ini file