pub unsafe extern "system" fn ColorMatchToTarget(
hdc: *mut c_void,
hdctarget: *mut c_void,
action: u32,
) -> i32Expand description
METAFILE#35 ColorMatchToTarget
specifies whether to perform color matching with a color profile that is specified in a file with a name
See also
- MS-EMF:v14 2.3.11.1 EMR_COLORMATCHTOTARGETW Record