pub unsafe extern "system" fn CreateDiscardableBitmap(
hdc: *mut c_void,
cx: i32,
cy: i32,
) -> *mut c_voidExpand description
#258 CreateDiscardableBitmap
create a bitmap that is compatible with the given device-context (DC)
specified in the hdc parameter, it can be discarded when it is not
selected into any DC