pub unsafe extern "system" fn CreatePolyPolygonRgn(
pptl: *const POINT,
pc: *const i32,
cpoly: i32,
imode: i32,
) -> *mut c_voidExpand description
#225 CreatePolyPolygonRgn
allocate storage for the region structure, initialize it to make a polygon region, and return a handle to the new region