pub unsafe extern "system" fn CreateRectRgn(
x1: i32,
y1: i32,
x2: i32,
y2: i32,
) -> *mut c_voidExpand description
#226 CreateRectRgn
allocate storage for the region structure, initialize it to make an rectangular region, and return a handle to the new region