pub unsafe extern "system" fn CreateRectRgnIndirect(
lprect: *const RECT,
) -> *mut c_voidExpand description
#226 CreateRectRgnIndirect
allocate storage for the region structure, initialize it to make an rectangular region, and return a handle to the new region