pub unsafe extern "system" fn CreateRoundRectRgn(
x1: i32,
y1: i32,
x2: i32,
y2: i32,
w: i32,
h: i32,
) -> *mut c_voidExpand description
#227 CreateRoundRectRgn
allocates storage for the region structure, initializes it to make a roundedcorner rectangular region, and returns a handle to the new region