pub unsafe extern "system" fn FillPath(hdc: *mut c_void) -> i32Expand description
METAFILE#10 FillPath
closes any open figures in the current path bracket and fills the path’s interior by using the current brush and polygon-filling mode
See also
- MS-EMF:v14 2.3.5.9 EMR_FILLPATH Record