pub unsafe extern "system" fn SetBrushOrgEx(
hdc: *mut c_void,
x: i32,
y: i32,
lppt: *mut POINT,
) -> i32Expand description
#245a SetBrushOrgEx
specifies the origin that will be given to the next brush that is selected into the specified device-context
See also
- MS-EMF:v14 2.3.11.12 EMR_SETBRUSHORGEX Record