pub unsafe extern "system" fn SetMetaRgn(hdc: *mut c_void) -> i32Expand description
METAFILE#6 SetMetaRgn
If the current metaregion is null, it is set to the current clipping region. Otherwise, the current metaregion is intersected with the current clipping region, and the result is the new metaregion
See also
- MS-EMF:v14 2.3.2 Clipping Record Types