pub unsafe extern "system" fn StrokeAndFillPath(
hdc: *mut c_void,
) -> i32Expand description
METAFILE#19 StrokeAndFillPath
closes any open figures in a path, strokes the outline of the path by using the current pen, and fills its interior by using the current brush
See also
- MS-EMF:v14 2.3.5.38 EMR_STROKEANDFILLPATH Record