pub unsafe extern "system" fn TabbedTextOut(
hdc: *mut c_void,
x: i32,
y: i32,
lpstring: *const u16,
chcount: i32,
ntabpositions: i32,
lpntabstoppositions: *const i32,
ntaborigin: i32,
) -> i32Expand description
#283 TabbedTextOut
provides the same basic functionality as the TextOut() function and also has three additional parameters to support the expansion of tabs in the text string.