pub unsafe extern "system" fn GlobalUnfix(hmem: *mut c_void)
#325 GlobalUnfix
#325
currently performs no operation.
originally allows the global memory object specified in the hmem parameter to be moved in linear memory
hmem