pub unsafe extern "system" fn SetDoubleClickTime(param0: u32) -> i32
#311 SetDoubleClickTime
#311
sets the maximum number of milliseconds that can occur between the first and second mouse button clicks of a mouse button double-click