DeferWindowPos

Function DeferWindowPos 

pub unsafe extern "system" fn DeferWindowPos(
    hwinposinfo: *mut c_void,
    hwnd: *mut c_void,
    hwndinsertafter: *mut c_void,
    x: i32,
    y: i32,
    cx: i32,
    cy: i32,
    uflags: u32,
) -> *mut c_void
#39 DeferWindowPos

fills a storage area with information for a window that is about to be moved, resized, shown, hidden, or activated