pub unsafe extern "system" fn GetClassWord(
hwnd: *mut c_void,
nindex: i32,
) -> u16Expand description
#24 GetClassWord
retrieve a word value at the specified offset from extra memory associated with the class associated with the specified window