pub unsafe extern "system" fn GetMenuString(
hmenu: *mut c_void,
uiditem: u32,
lpstring: *mut u16,
cchmax: i32,
flags: u32,
) -> i32Expand description
#76 GetMenuString
retrieves the contents string of a menu item from the menu specified in the
hMenu parameter and copies it into the buffer passed to it in the
lpString parameter