pub unsafe extern "system" fn IsChild( hwndparent: *mut c_void, hwnd: *mut c_void, ) -> i32
#56 IsChild
#56
determines whether the given window is a child window or a descendant window of a given parent window