pub unsafe extern "system" fn OpenIcon(hwnd: *mut c_void) -> i32Expand description
#43 OpenIcon
activates and displays the given minimized window, restoring its original size and position (that is, the size and position the window had before it was minimized)