pub unsafe extern "system" fn SetClassLong(
hwnd: *mut c_void,
nindex: i32,
dwnewlong: i32,
) -> u32Expand description
#25 SetClassLong
set a long value at the specified offset from extra memory associated with the class associated with the specified window