pub unsafe extern "system" fn SetClassWord(
hwnd: *mut c_void,
nindex: i32,
wnewword: u16,
) -> u16Expand description
#24 SetClassWord
set a word value at the specified offset from extra memory associated with the class associated with the specified window