pub type DialogProc = <DLGPROC as OptInner>::Inner;Expand description
#149 DialogProc
a callback function, defined by the application, that processes messages that are sent to a modeless dialog box
pub type DialogProc = <DLGPROC as OptInner>::Inner;#149 DialogProc
a callback function, defined by the application, that processes messages that are sent to a modeless dialog box