SysMsgProc

Type Alias SysMsgProc 

pub type SysMsgProc = <HOOKPROC as OptInner>::Inner;
#123 SysMsgProc

called by the system after a dialog box, message box, or menu has fetched a message but before the message has been processed